==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/70/7078641b30d6000711852b09932024bc.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/IntegrationsBundle/Controller/UpdateFieldController.php */
class __TwigTemplate_a3ea7457c1d0b3ff59cb047e2a7ce2b1 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\IntegrationsBundle\\Controller;

use Mautic\\CoreBundle\\Controller\\CommonController;
use Symfony\\Component\\HttpFoundation\\JsonResponse;
use Symfony\\Component\\HttpFoundation\\Request;

class UpdateFieldController extends CommonController
{
    public function updateAction(Request \$request, string \$integration, string \$object, string \$field): JsonResponse
    {
        // Clear the session of previously stored fields in case it got stuck
        \$session       = \$request->getSession();
        \$updatedFields = \$session->get(sprintf('%s-fields', \$integration), []);

        if (!isset(\$updatedFields[\$object])) {
            \$updatedFields[\$object] = [];
        }

        if (!isset(\$updatedFields[\$object][\$field])) {
            \$updatedFields[\$object][\$field] = [];
        }

        if (\$mappedField = \$request->request->get('mappedField')) {
            \$updatedFields[\$object][\$field]['mappedField'] = \$mappedField;
        }

        if (\$syncDirection = \$request->request->get('syncDirection')) {
            \$updatedFields[\$object][\$field]['syncDirection'] = \$syncDirection;
        }

        \$session->set(sprintf('%s-fields', \$integration), \$updatedFields);

        return new JsonResponse([]);
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/IntegrationsBundle/Controller/UpdateFieldController.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/IntegrationsBundle/Controller/UpdateFieldController.php", "/var/www/html/mauticGIT-Test/app/bundles/IntegrationsBundle/Controller/UpdateFieldController.php");
    }
}

==> production-demo-20260214_152721.tar.gz: var/www/html/production-demo/var/tmp/twig/70/7078641b30d6000711852b09932024bc.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/IntegrationsBundle/Controller/UpdateFieldController.php */
class __TwigTemplate_a3ea7457c1d0b3ff59cb047e2a7ce2b1 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\IntegrationsBundle\\Controller;

use Mautic\\CoreBundle\\Controller\\CommonController;
use Symfony\\Component\\HttpFoundation\\JsonResponse;
use Symfony\\Component\\HttpFoundation\\Request;

class UpdateFieldController extends CommonController
{
    public function updateAction(Request \$request, string \$integration, string \$object, string \$field): JsonResponse
    {
        // Clear the session of previously stored fields in case it got stuck
        \$session       = \$request->getSession();
        \$updatedFields = \$session->get(sprintf('%s-fields', \$integration), []);

        if (!isset(\$updatedFields[\$object])) {
            \$updatedFields[\$object] = [];
        }

        if (!isset(\$updatedFields[\$object][\$field])) {
            \$updatedFields[\$object][\$field] = [];
        }

        if (\$mappedField = \$request->request->get('mappedField')) {
            \$updatedFields[\$object][\$field]['mappedField'] = \$mappedField;
        }

        if (\$syncDirection = \$request->request->get('syncDirection')) {
            \$updatedFields[\$object][\$field]['syncDirection'] = \$syncDirection;
        }

        \$session->set(sprintf('%s-fields', \$integration), \$updatedFields);

        return new JsonResponse([]);
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/IntegrationsBundle/Controller/UpdateFieldController.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/IntegrationsBundle/Controller/UpdateFieldController.php", "/var/www/html/production-demo/app/bundles/IntegrationsBundle/Controller/UpdateFieldController.php");
    }
}
